@@ -1,5 +1,4 @@
 import csv
-import io
 import sys
 import tempfile
 from uuid import uuid4
@@ -15,6 +14,7 @@ from kolibri.core.auth.constants import demographics
 from kolibri.core.auth.constants import role_kinds
 from kolibri.core.auth.models import Classroom
 from kolibri.core.auth.models import FacilityUser
+from kolibri.core.utils.csv import open_csv_for_writing
 
 if sys.version_info[0] < 3:
     from cStringIO import StringIO
@@ -118,10 +118,7 @@ class ImportTestCase(TestCase):
     def create_csv(self, filepath, rows, remove_uuid=False):
         header_labels = list(labels.values())
 
-        if sys.version_info[0] < 3:
-            csv_file = io.open(filepath, "wb")
-        else:
-            csv_file = io.open(filepath, "w", newline="")
+        csv_file = open_csv_for_writing(filepath)
 
         with csv_file as f:
             writer = csv.writer(f)
@@ -135,7 +132,7 @@ class ImportTestCase(TestCase):
         # Replace asterisk in passwords to be able to import it
         # Remove UUID so new users are created
         _, new_filepath = tempfile.mkstemp(suffix=".csv")
-        rows = list()
+        rows = []
         with open(self.filepath) as source:
             reader = csv.reader(source, strict=True)
             for row in reader:
@@ -166,7 +163,7 @@ class ImportTestCase(TestCase):
                 reader, header_translation
             )
 
-        assert len(users) == 12  # admins have not been exported
+        assert len(users) == 10  # admins have not been exported
         # assert roles[role_kinds.ADMIN] == ["facadmin"]
         assert per_line_errors == []
         assert roles[role_kinds.COACH] == ["faccoach"]
@@ -496,7 +493,7 @@ class ImportTestCase(TestCase):
     def test_non_existing_uuid(self):
         self.import_exported_csv()
         _, new_filepath = tempfile.mkstemp(suffix=".csv")
-        rows = list()
+        rows = []
         with open(self.filepath) as source:
             reader = csv.reader(source, strict=True)
             for row in reader:
