@@ -112,6 +112,14 @@ class Command(AsyncCommand):
             help="Import all updated content after a channel version upgrade",
         )
 
+        parser.add_argument(
+            "--fail-on-error",
+            action="store_true",
+            default=False,
+            dest="fail_on_error",
+            help="Raise an error when a file has failed to be imported",
+        )
+
         # to implement these two groups of commands and their corresponding
         # arguments, we'll need argparse.subparsers.
         subparsers = parser.add_subparsers(
@@ -144,6 +152,14 @@ class Command(AsyncCommand):
             "--peer_id", type=str, default="", dest="peer_id"
         )
 
+        network_subparser.add_argument(
+            "--timeout",
+            type=int,
+            default=transfer.Transfer.DEFAULT_TIMEOUT,
+            dest="timeout",
+            help="Specify network timeout in seconds (default: %(default)d)",
+        )
+
         disk_subparser = subparsers.add_parser(
             name="disk", cmd=self, help="Copy the content from the given folder."
         )
@@ -160,6 +176,8 @@ class Command(AsyncCommand):
         peer_id=None,
         renderable_only=True,
         import_updates=False,
+        fail_on_error=False,
+        timeout=transfer.Transfer.DEFAULT_TIMEOUT,
     ):
         self._transfer(
             DOWNLOAD_METHOD,
@@ -170,6 +188,8 @@ class Command(AsyncCommand):
             peer_id=peer_id,
             renderable_only=renderable_only,
             import_updates=import_updates,
+            fail_on_error=fail_on_error,
+            timeout=timeout,
         )
 
     def copy_content(
@@ -181,6 +201,7 @@ class Command(AsyncCommand):
         exclude_node_ids=None,
         renderable_only=True,
         import_updates=False,
+        fail_on_error=False,
     ):
         self._transfer(
             COPY_METHOD,
@@ -191,6 +212,7 @@ class Command(AsyncCommand):
             exclude_node_ids=exclude_node_ids,
             renderable_only=renderable_only,
             import_updates=import_updates,
+            fail_on_error=fail_on_error,
         )
 
     def _transfer(  # noqa: max-complexity=16
@@ -205,6 +227,8 @@ class Command(AsyncCommand):
         peer_id=None,
         renderable_only=True,
         import_updates=False,
+        fail_on_error=False,
+        timeout=transfer.Transfer.DEFAULT_TIMEOUT,
     ):
         try:
             if not import_updates:
@@ -379,6 +403,7 @@ class Command(AsyncCommand):
                                     dest,
                                     session=session,
                                     cancel_check=self.is_cancelled,
+                                    timeout=timeout,
                                 )
                             elif method == COPY_METHOD:
                                 try:
@@ -426,8 +451,10 @@ class Command(AsyncCommand):
                             logger.error(
                                 "An error occurred during content import: {}".format(e)
                             )
+
                             if (
-                                isinstance(e, requests.exceptions.HTTPError)
+                                not fail_on_error
+                                and isinstance(e, requests.exceptions.HTTPError)
                                 and e.response.status_code == 404
                             ) or (isinstance(e, OSError) and e.errno == 2):
                                 # Continue file import when the current file is not found from the source and is skipped.
@@ -537,6 +564,8 @@ class Command(AsyncCommand):
                 peer_id=options["peer_id"],
                 renderable_only=options["renderable_only"],
                 import_updates=options["import_updates"],
+                fail_on_error=options["fail_on_error"],
+                timeout=options["timeout"],
             )
         elif options["command"] == "disk":
             self.copy_content(
@@ -547,6 +576,7 @@ class Command(AsyncCommand):
                 exclude_node_ids=options["exclude_node_ids"],
                 renderable_only=options["renderable_only"],
                 import_updates=options["import_updates"],
+                fail_on_error=options["fail_on_error"],
             )
         else:
             self._parser.print_help()
