@@ -29,6 +29,7 @@ from kolibri.core.content.models import AssessmentMetaData
 from kolibri.core.content.models import ChannelMetadata
 from kolibri.core.content.models import ContentNode
 from kolibri.core.content.models import File
+from kolibri.core.content.models import Language
 from kolibri.core.content.models import LocalFile
 from kolibri.core.content.utils.annotation import recurse_annotation_up_tree
 from kolibri.core.content.utils.annotation import (
@@ -476,6 +477,17 @@ class NaiveImportTestCase(ContentNodeTestBase, ContentImportTestBase):
         with self.assertRaises(ContentNode.DoesNotExist):
             assert ContentNode.objects.get(pk=obj_id)
 
+    def test_residual_included_languages_deleted_after_reimport(self):
+        lang = Language.objects.create(id="en")
+        channel = ChannelMetadata.objects.first()
+        # Decrement current channel version to ensure reimport
+        channel.version -= 1
+        channel.included_languages.add(lang)
+        channel.save()
+        self.set_content_fixture()
+        channel = ChannelMetadata.objects.first()
+        self.assertEqual(channel.included_languages.count(), 0)
+
     def test_prerequisites_not_duplicated(self):
         prereqs = ContentNode.has_prerequisite.through.objects.all().count()
         channel = ChannelMetadata.objects.first()
