@@ -16,6 +16,7 @@ from morango.models import UUIDField
 
 from kolibri.core.fields import DateTimeTzField
 from kolibri.core.fields import JSONField
+from kolibri.deployment.default.sqlite_db_names import NOTIFICATIONS
 from kolibri.utils.time_utils import local_now
 
 # Remove NotificationsRouter if sqlite is not being used:
@@ -31,21 +32,18 @@ class NotificationsRouter(object):
     """
     Determine how to route database calls for the Notifications app.
     All other models will be routed to the default database.
-
-    If using sqlite, this command must be executed to run migrations under this router:
-        `kolibri manage migrate notifications --database=notifications_db`
     """
 
     def db_for_read(self, model, **hints):
-        """Send all read operations on Notifications app models to `notifications_db`."""
+        """Send all read operations on Notifications app models to NOTIFICATIONS."""
         if model._meta.app_label == "notifications":
-            return "notifications_db"
+            return NOTIFICATIONS
         return None
 
     def db_for_write(self, model, **hints):
-        """Send all write operations on Notifications app models to `notifications_db`."""
+        """Send all write operations on Notifications app models to NOTIFICATIONS."""
         if model._meta.app_label == "notifications":
-            return "notifications_db"
+            return NOTIFICATIONS
         return None
 
     def allow_relation(self, obj1, obj2, **hints):
@@ -67,10 +65,10 @@ class NotificationsRouter(object):
     def allow_migrate(self, db, app_label, model_name=None, **hints):
         """Ensure that the Notifications app's models get created on the right database."""
         if app_label == "notifications":
-            # The Notifications app should be migrated only on the notifications_db database.
-            return db == "notifications_db"
-        elif db == "notifications_db":
-            # Ensure that all other apps don't get migrated on the notifications_db database.
+            # The Notifications app should be migrated only on the NOTIFICATIONS database.
+            return db == NOTIFICATIONS
+        elif db == NOTIFICATIONS:
+            # Ensure that all other apps don't get migrated on the NOTIFICATIONS database.
             return False
 
         # No opinion for all other scenarios
