@@ -2,6 +2,8 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
+import os
+
 from .base import *  # noqa isort:skip @UnusedWildImport
 
 DEBUG = True
@@ -22,6 +24,7 @@ INTERNAL_IPS = ["127.0.0.1"]
 ROOT_URLCONF = "kolibri.deployment.default.dev_urls"
 
 DEVELOPER_MODE = True
+os.environ.update({"KOLIBRI_DEVELOPER_MODE": "True"})
 
 try:
     process_cache = CACHES["process_cache"]  # noqa F405
@@ -31,7 +34,7 @@ except KeyError:
 # Create a memcache for each cache
 CACHES = {
     key: {"BACKEND": "django.core.cache.backends.locmem.LocMemCache"}
-    for key in CACHES.keys()  # noqa F405
+    for key in CACHES  # noqa F405
 }
 
 if process_cache:
